# msprime  <img align="right" width="145" height="90" src="https://raw.githubusercontent.com/tskit-dev/msprime/main/docs/msprime_logo.svg">

[![codecov](https://codecov.io/gh/tskit-dev/msprime/branch/main/graph/badge.svg)](https://codecov.io/gh/tskit-dev/msprime) [![PyPI Downloads](https://pepy.tech/badge/msprime)](https://pepy.tech/project/msprime) [![Conda Downloads](https://anaconda.org/conda-forge/msprime/badges/downloads.svg)](https://anaconda.org/conda-forge/msprime) [![SWH](https://archive.softwareheritage.org/badge/origin/https://github.com/tskit-dev/msprime/)](https://archive.softwareheritage.org/browse/origin/?origin_url=https://github.com/tskit-dev/msprime) [![Docs Build](https://github.com/tskit-dev/msprime/actions/workflows/docs.yml/badge.svg)](https://github.com/tskit-dev/msprime/actions/workflows/docs.yml) [![Binary wheels](https://github.com/tskit-dev/msprime/actions/workflows/wheels.yml/badge.svg)](https://github.com/tskit-dev/msprime/actions/workflows/wheels.yml) [![Tests](https://github.com/tskit-dev/msprime/actions/workflows/tests.yml/badge.svg)](https://github.com/tskit-dev/msprime/actions/workflows/tests.yml)


``msprime`` is a population genetics simulator
based on [tskit](https://tskit.dev). Msprime can simulate random
ancestral histories for a sample of individuals
(consistent with a given demographic model) under a
range of different models and evolutionary processes. Msprime can
also simulate mutations on a given ancestral
history (which can be produced by msprime or other programs
supporting [tskit](https://tskit.dev)) under
a variety of genome sequence evolution models.

Please see the [documentation](https://tskit.dev/msprime/docs/latest/) for
more details, including
[installation instructions](https://tskit.dev/msprime/docs/latest/installation.html).

